marktools.get_lilypond_command_marks_attached_to_component
==========================================================

.. autofunction:: abjad.tools.marktools.get_lilypond_command_marks_attached_to_component.get_lilypond_command_marks_attached_to_component
